<?php
/**
 * Theme functions and definitions
 *
 * @package Presto_Fashion_Blogger
 */

/**
 * Customizer
 */
require get_stylesheet_directory() . '/inc/customizer.php';

/**
 * After setup theme hook
 */
function presto_fashion_blogger_theme_setup(){
    /*
     * Make child theme available for translation.
     * Translations can be filed in the /languages/ directory.
     */
    load_child_theme_textdomain( 'presto-fashion-blogger', get_stylesheet_directory() . '/languages' );  
    
    add_image_size( 'presto-fashion-blogger-slider', 446, 595, true );
}
add_action( 'after_setup_theme', 'presto_fashion_blogger_theme_setup' );

/**
 * Load assets.
 */
function presto_fashion_blogger_enqueue_styles() {
    // Use minified libraries if SCRIPT_DEBUG is false
    $suffix      = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';
    $slider_auto = get_theme_mod( 'slider_auto', false );

    if( presto_blog_is_woocommerce_activated() ){
        $dependency = array( 'presto-blog-google-fonts', 'presto-blog-gutenberg', 'presto-blog-woo', 'presto-blog-style' );
    }else{
        $dependency = array( 'presto-blog-google-fonts', 'presto-blog-gutenberg', 'presto-blog-style' );
    }

    wp_enqueue_style( 'swiper-bundle', get_stylesheet_directory_uri(). '/assets/css/swiper-bundle' . $suffix . '.css', array(), '6.8.1' );
    wp_enqueue_style( 'presto-fashion-blogger', get_stylesheet_directory_uri() . '/style.css', $dependency, PRESTO_BLOG_VERSION );
	
    wp_enqueue_script( 'swiper-bundle', get_stylesheet_directory_uri() . '/assets/js/swiper-bundle' . $suffix . '.js', array(), '6.8.1', true );
	wp_enqueue_script( 'presto-fashion-blogger', get_stylesheet_directory_uri() . '/assets/js/custom' . $suffix . '.js', array( 'jquery', 'presto-blog-accessibility', 'presto-blog-custom' ), PRESTO_BLOG_VERSION, true );

    wp_localize_script( 
        'presto-fashion-blogger', 
        'presto_fashion_blogger',
        array(
            'slider_auto' => $slider_auto,
        )
    );
}
add_action( 'wp_enqueue_scripts', 'presto_fashion_blogger_enqueue_styles' );

function presto_blog_header(){ 
    get_template_part( 'headers/eight' );    
}

function presto_blog_body_classes( $classes ) {	
	$editor_options      = get_option( 'classic-editor-replace' );
	$allow_users_options = get_option( 'classic-editor-allow-users' );
	$ed_banner_section   = get_theme_mod( 'ed_banner_section', 'no_banner' );
 
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

    $classes[] = 'header-layout-eight';

    if( $ed_banner_section == 'static_banner' ){
        $classes[] = 'hs-static-banner static-banner-layout-one';        
    }elseif( $ed_banner_section == 'slider_banner' ){
        $classes[] = "slider-layout-five";
    }

    if( is_single() ){
        $classes[] = 'single-layout1';
    }
    
	if ( ! is_singular() && !( presto_blog_is_woocommerce_activated() && ( is_shop() || is_product_category() || is_product_tag() ) ) && !is_404() ) {	
		$classes[] = 'post-list-style5';
	}

	if ( !presto_blog_is_classic_editor_activated() || ( presto_blog_is_classic_editor_activated() && $editor_options == 'block' ) || ( presto_blog_is_classic_editor_activated() && $allow_users_options == 'allow' && has_blocks() ) ) {
        $classes[] = 'presto-blog-has-blocks';
    }

	$classes[] = presto_blog_sidebar( true );

	return $classes;
}

function presto_blog_instagram(){
    $ed_instagram_section       = get_theme_mod( 'ed_instagram_section', false );
    $instagram_title            = get_theme_mod( 'instagram_title',__( 'I\'m on instagram', 'presto-fashion-blogger' ) );
    $instagram_shortcode        = get_theme_mod( 'instagram_shortcode' );
    if( $ed_instagram_section && $instagram_title && $instagram_shortcode ){ ?>
        <div class="instagram-section insta-layout-3">
            <?php if( $instagram_title ) echo '<h2 class="section-title">' . esc_html( $instagram_title ). '</h2>'; ?>
            <?php if( $instagram_shortcode ) echo do_shortcode( wp_kses_post( $instagram_shortcode ) ); ?>
        </div>
        <?php 
    }
}

function presto_blog_banner(){
	$ed_banner             = get_theme_mod( 'ed_banner_section', 'slider_banner' );
	$banner_subtitle       = get_theme_mod( 'banner_subtitle', __( 'Free Blogging Course','presto-fashion-blogger' ) );
	$banner_title          = get_theme_mod( 'banner_title', __( 'Are you Ready to Start a Profitable Blog?','presto-fashion-blogger' ) );
	$banner_link_one_label = get_theme_mod( 'banner_link_one_label', __( 'Get Started','presto-fashion-blogger' ) );
	$banner_link_one_url   = get_theme_mod( 'banner_link_one_url','#' );
	$banner_link_two_label = get_theme_mod( 'banner_link_two_label', __( 'Learn More','presto-fashion-blogger' ) );
	$banner_link_two_url   = get_theme_mod( 'banner_link_two_url','#' );
	$no_of_slides          = get_theme_mod( 'no_of_slides', 5 );

	if( is_front_page() ){
		if( has_custom_header() && $ed_banner == 'static_banner' ){ ?>
            <div id="banner_section" class="site-banner layout-one banner-static">
                <div class="banner-items">
                    <div class="banner-item">
                        <?php 
                            the_custom_header_markup();
                            
                            if( $ed_banner == 'static_banner' && ( $banner_subtitle || $banner_title || ( $banner_link_one_label && $banner_link_one_url )  || ( $banner_link_two_label && $banner_link_two_url ) ) ){ ?>
                                <div class="item-content">
                                    <div class="container">
                                        <div class="item-content-inner">
                                            <?php 
                                                if( $banner_subtitle ){ ?>
                                                    <span class="sub-title"><?php echo esc_html( $banner_subtitle ); ?></span>
                                                    <?php 
                                                }
                                                if( $banner_title ){ ?>
                                                    <h2 class="item-title"><?php echo esc_html( $banner_title ); ?></h2>
                                                    <?php 
                                                }
                                                
                                                if( ( $banner_link_one_label && $banner_link_one_url ) || ( $banner_link_two_label && $banner_link_two_url ) ){ ?>
                                                    <div class="banner-desc-wrap">
                                                        <div class="btn-wrap">
                                                            <?php 
                                                                if( $banner_link_one_label && $banner_link_one_url ) { ?>
                                                                    <a href="<?php echo esc_url( $banner_link_one_url ); ?>" class="btn"><?php echo esc_html( $banner_link_one_label ); ?></a>
                                                                    <?php 
                                                                }
                                                                if( $banner_link_two_label && $banner_link_two_url ) { ?>
                                                                    <a href="<?php echo esc_url( $banner_link_two_url ); ?>" class="btn btn-outlined"><?php echo esc_html( $banner_link_two_label ); ?></a>
                                                                    <?php 
                                                                } 
                                                            ?>
                                                        </div>
                                                    </div>
                                                    <?php 
                                                }       
                                            ?>
                                        </div>
                                    </div>
                                </div>
                                <?php 
                            }
                        ?>
                    </div>
                </div>
            </div><!-- .site-banner -->
		    <?php 
		}elseif( $ed_banner == 'slider_banner' ){
            $args = array(
                'post_status'         => 'publish',
                'ignore_sticky_posts' => true,
                'post_type'           => 'post',
                'posts_per_page'      => $no_of_slides,
            );

            $qry = new WP_Query( $args );
            
            if( $qry->have_posts() ){ ?>
                <div id="banner_section" class="site-banner banner-slider layout-five">
                    <div class="swiper-container"<?php if( is_rtl() ) echo ' dir="rtl"'; ?>>
                        <div class="banner-items swiper-wrapper">
                            <?php 
                                while( $qry->have_posts() ){ 
                                    $qry->the_post(); ?> 
                                        <div class="banner-item swiper-slide">
                                            <div class="slider-img-holder">
                                                <?php
                                                    if( has_post_thumbnail() ){
                                                        the_post_thumbnail( 'presto-fashion-blogger-slider', array( 'itemprop' => 'image' ) );    
                                                    }else{ 
                                                        presto_blog_get_fallback_svg( 'presto-fashion-blogger-slider' );
                                                    }
                                                ?>
                                            </div>
                                            <div class="item-content">
                                                <div class="item-content-inner">
                                                    <?php presto_blog_category(); ?>
                                                    <h2 class="item-title">
                                                        <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                                    </h2>
                                                    <div class="item-meta">
                                                        <?php presto_blog_posted_on(); ?>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    <?php
                                } 
                            ?>
                        </div>
                        <button class="swiper-arrow swiper-btn-prev">
                            <?php echo presto_blog_svg_collection( 'swiper-prev' ); ?>
                        </button>
                        <button class="swiper-arrow swiper-btn-next">
                            <?php echo presto_blog_svg_collection( 'swiper-next' ); ?>
                        </button>
                        <div class="swiper-pagination"></div>
                    </div>
                </div><!-- .site-banner -->
                <?php
            }
            wp_reset_postdata();
        }   
	}
}

function presto_blog_google_fonts_url() {
    $fonts_url = '';
    $fonts     = array();

    /*
    * translators: If there are characters in your language that are not supported
    * by DM Sans, translate this to 'off'. Do not translate into your own language.
    */
    if ( 'off' !== _x( 'on', 'DM Sans font: on or off', 'presto-fashion-blogger' ) ) {
        $fonts[] = 'DM Sans:regular,italic,500,500italic,700,700italic';
    }

    /*
    * translators: If there are characters in your language that are not supported
    * by Bodoni Moda:, translate this to 'off'. Do not translate into your own language.
    */
    if ( 'off' !== _x( 'on', 'EB Garamond: font: on or off', 'presto-fashion-blogger' ) ) {
        $fonts[] = 'EB Garamond:600,600italic';
    }

    if ( $fonts ) {
        $fonts_url = add_query_arg(
            array(
                'family'  => urlencode( implode( '|', $fonts ) ),
                'display' => urlencode( 'swap' ),
            ),
            'https://fonts.googleapis.com/css'
        );
    }

    return esc_url( $fonts_url );
}

function presto_blog_author_link(){    
    echo '<span class="author-link">'; 
    esc_html_e( ' Presto Fashion Blogger | Developed By ', 'presto-fashion-blogger' );
    echo '<a href="' . esc_url( 'https://sublimetheme.com/' ) .'" rel="nofollow" target="_blank">' . esc_html__( 'SublimeTheme', 'presto-fashion-blogger' ) . '</a></span>.';
}

/**
 * Exclude post with Category from blog and archive page. 
*/
function presto_blog_exclude_cat( $query ){    
    $home_featured_post = get_theme_mod( 'home_featured_post' );
    $ed_banner          = get_theme_mod( 'ed_banner_section', 'slider_banner' );
    $posts_per_page     = get_theme_mod( 'no_of_slides', 5 );
    $excludes           = array();
    
    if( ! is_admin() && $query->is_main_query() && $query->is_home() ){        
        if( ( $ed_banner == 'slider_banner' ) ){                        
            $args = array(
                'post_type'           => 'post',
                'post_status'         => 'publish',
                'posts_per_page'      => $posts_per_page,
                'ignore_sticky_posts' => true
            );
            $latest = get_posts( $args );                
            foreach( $latest as $l ){
                array_push( $excludes, $l->ID );
            }
        }

        if( $home_featured_post ){
            $home_featured_post = array_map( 'intval', $home_featured_post );
            $excludes = array_diff( array_unique( array_merge( $excludes, $home_featured_post ) ), array('') );
        }

        $query->set( 'post__not_in', $excludes );
    }      
}